/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { ICreateDataSetOptions } from './doc/ICreateDataSetOptions';
import { IUploadRseOptions } from '../upload';
/**
 * Class to handle creation of data sets
 */
export declare class Create {
    /**
     * Create a data set
     * @param {Session} session                             - REST API connection info
     * @param {CreateDataSetTypeEnum} cmdType               - The type of data set we are going to create
     * @param {string} dataSetName                          - the name of the data set to create
     * @param {Partial<ICreateDataSetOptions>} [options={}] - additional options for the creation of the data set
     * @returns {Promise<IZosFilesResponse>}
     */
    static dataSet(session: Session, cmdType: zowe.CreateDataSetTypeEnum, dataSetName: string, options?: Partial<ICreateDataSetOptions>): Promise<IRestApiResponse>;
    /**
     * Validate supplied parameters
     * @static
     * @param options - additional options for the creation of the data set
     */
    static dataSetValidateOptions(options: ICreateDataSetOptions): void;
    /**
     * Create a data set like another data set
     * @param {Session} session                             - REST API connection info
     * @param {string} dataSetName                          - the name of the data set to create
     * @param {string} likeDsName                           - the name of the data set with attributes to use for new ds
     * @param {Partial<ICreateDataSetOptions>} [options={}] - additional options for the creation of the data set
     * @returns {Promise<IZosFilesResponse>}
     */
    static allocateLike(session: Session, dataSetName: string, likeDsName: string, options?: Partial<ICreateDataSetOptions>): Promise<IRestApiResponse>;
    static createMember(session: Session, dataSetName: string, options?: IUploadRseOptions): Promise<IRestApiResponse>;
    /**
     * Create a uss file or folder
     * @param {Session} session                      - RSE connection info
     * @param {string} ussPath                       - USS path to create file or directory
     * @param <ICreateUssOptions> options?           - the options.type "f" for file or "d" for directory
     *                                               - the options.permissions for the permissions for "file" or "directory"
     * @returns {Promise<IZosFilesResponse>}
     */
    static uss(session: Session, ussPath: string, type: string, mode?: string): Promise<IRestApiResponse>;
    static getAttributes(session: Session, dsName: string, attrs: zowe.IListOptions): Promise<unknown>;
    private static alcUnitValidation;
    private static dirBlkValidation;
    private static dsOrgValidation;
    private static dsnTypeValidation;
    private static primaryValidation;
    private static secondaryValidation;
    private static recordFormatValidation;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
